--------------------------------------------------------------------------------
-- Weapon Airstrike + Projectile Cluster
-- Original Carnage Contest Weapon
-- Script by DC, August 2009, www.UnrealSoftware.de
-- modded by Kiffer-Opa
--------------------------------------------------------------------------------

-- Setup Tables
if ccm==nil then ccm={} end
ccm.airstrike={}
ccm.airstrike.cluster={}
ccm.airstrike.plane={}

-- Load & Prepare Ressources
ccm.airstrike.gfx_wpn=loadgfx("weapons/rc.bmp")							-- Weapon Image
setmidhandle(ccm.airstrike.gfx_wpn)
ccm.airstrike.gfx_icon=loadgfx("weapons/airstrikeicon.png")				-- Weapon Icon
setmidhandle(ccm.airstrike.gfx_icon)
ccm.airstrike.gfx_pro=loadgfx("weapons/cluster.bmp")						-- Projectile Image
setmidhandle(ccm.airstrike.gfx_pro)
ccm.airstrike.gfx_plane=loadgfx("weapons/airstrike_airplane.png")
setmidhandle(ccm.airstrike.gfx_plane)
ccm.airstrike.sfx_attack=loadsfx("airstrike.ogg")						-- Attack Sound

--------------------------------------------------------------------------------
-- Weapon: Airstrike
--------------------------------------------------------------------------------
ccm.airstrike.id=addweapon("ccm.airstrike","Air Strike",ccm.airstrike.gfx_icon,1,2)	-- Add Weapon (1 use, first in round 2)

--------------
-- Airplane --
--------------
ccm.airstrike.plane.id=addprojectile("ccm.airstrike.plane")

function ccm.airstrike.plane.draw(id)
	local dir
	-- direction
	if(projectiles[id].sx>0) then
		dir=1
	else
		dir=-1
	end
	setblend(blend_alpha)
	setalpha(1)
	setcolor(255,255,255)
	setscale(dir,1)
	setrotation(0)
	drawimage(ccm.airstrike.gfx_plane,projectiles[id].x,projectiles[id].y)
	if(weapon_mode==0) then
		scroll(projectiles[id].x,projectiles[id].y)
	end
end

function ccm.airstrike.plane.update(id)
	local dir
	if(projectiles[id].sx>0) then
		dir=1
	else
		dir=-1
	end
	-- Particles
	particle(p_smoke, projectiles[id].x-55*dir, projectiles[id].y+11)
	particlespeed(math.random(-2,2)*0.1, math.random(-2,2)*0.1)
	particlefadealpha(0.01)
	
	particle(p_lightpuff,projectiles[id].x-55*dir, projectiles[id].y+11)
	particlefadealpha(0.04)

	-- move
	projectiles[id].x=projectiles[id].x+projectiles[id].sx

	if weapon_mode==0 then
		local dropx=projectiles[id].throwindex*15*dir
		if(dir==1 and projectiles[id].x>=weapon_x+dropx) or (dir==-1 and projectiles[id].x<=weapon_x+dropx) then
			-- Attack
			projectiles[id].throwindex=projectiles[id].throwindex+1
			pid=createprojectile(ccm.airstrike.cluster.id)
			projectiles[pid]={}
			projectiles[pid].x=weapon_x+dropx
			projectiles[pid].y=-500
			projectiles[pid].sx=1.5*dir
			projectiles[pid].sy=3.0 
			if projectiles[id].throwindex==0 then
				projectiles[pid].follow=true
			else
				projectiles[pid].follow=false
			end
			if(projectiles[id].throwindex>2) then
				weapon_mode=1
			end
		end
	end
		
	-- remove plane
	if(dir==1 and projectiles[id].x>weapon_x+1000 and projectiles[id].x>(getmapwidth()+1000)) or (dir==-1 and projectiles[id].x<weapon_x-1000 and projectiles[id].x<-1000) then
		freeprojectile(id)
	end
end

----------------
-- Air Strike --
----------------

function ccm.airstrike.draw()													-- Draw
	setblend(blend_alpha)
	setalpha(1)
	setcolor(255,255,255)
	drawinhand(ccm.airstrike.gfx_wpn,7,0)
	-- HUD Positioning
	if weapon_shots==0 then
		hudpositioning(pos_invisible)
	end
end

function ccm.airstrike.attack(attack)									-- Attack
	if (weapon_shots<=0) and (weapon_position==1) then
		-- No more weapon switching!
		useweapon(0)
		playsound(ccm.airstrike.sfx_attack)
		weapon_shots=weapon_shots+1
		id=createprojectile(ccm.airstrike.plane.id)
		projectiles[id]={}
		if(getplayerdirection(0)==1) then
			projectiles[id].x=math.min(weapon_x-1000, -1000)
			projectiles[id].sx=40
		else
			projectiles[id].x=math.max(weapon_x+1000, getmapwidth()+1000)
			projectiles[id].sx=-40
		end
		projectiles[id].y=-512
		projectiles[id].throwindex=-2
		-- End Turn
		endturn()
	end
end

--------------------------------------------------------------------------------
-- Projectile: Cluster
--------------------------------------------------------------------------------

ccm.airstrike.cluster.id=addprojectile("ccm.airstrike.cluster")	-- Add Projectile

function ccm.airstrike.cluster.draw(id)							-- Draw
	-- Setup draw mode
	setblend(blend_alpha)
	setalpha(1)
	setcolor(255,255,255)
	setscale(1,1)
	-- Calculate projectile rotation
	setrotation(math.deg(math.atan2(projectiles[id].sx,-projectiles[id].sy)))
	-- Draw projectile
	drawimage(ccm.airstrike.gfx_pro,projectiles[id].x,projectiles[id].y)
end

function ccm.airstrike.cluster.update(id)							-- Update
	rot=math.deg(math.atan2(projectiles[id].sx,-projectiles[id].sy))
	-- Particle Tail
	particle(p_smoke,projectiles[id].x-math.sin(math.rad(rot))*7,projectiles[id].y+math.cos(math.rad(rot))*7)
	particlespeed(math.random(-2,2)*0.1,math.random(-2,2)*0.1)
	particlefadealpha(0.05)
	-- Wind + Gravity influence on speed
	projectiles[id].sx=projectiles[id].sx+getwind()*0.3
	projectiles[id].sy=projectiles[id].sy+getgravity()
	-- Move (in substep loop for optimal collision precision)
	msubt=math.ceil(math.max(math.abs(projectiles[id].sx),math.abs(projectiles[id].sy))/3)
	msubx=projectiles[id].sx/msubt
	msuby=projectiles[id].sy/msubt
	for i=1,msubt,1 do
		projectiles[id].x=projectiles[id].x+msubx
		projectiles[id].y=projectiles[id].y+msuby
		-- Collision
		if collision(col3x3,projectiles[id].x,projectiles[id].y)==1 then
			-- Cause damage
			arealdamage(projectiles[id].x,projectiles[id].y,70,25)
			-- Destroy terrain
			terrainexplosion(projectiles[id].x,projectiles[id].y,15,1)
			-- Crater
			grey=math.random(0,40)
			terrainalphaimage(gfx_crater75,projectiles[id].x,projectiles[id].y,math.random(5,7)*0.1,grey,grey,grey)
			-- Free projectile
			freeprojectile(id)
			break
		end
		-- Water
		if (projectiles[id].y)>getwatery()+5 then
			-- Effects
			particle(p_waterhit,projectiles[id].x,projectiles[id].y)
			playsound(sfx_hitwater1)
			-- Free projectile
			freeprojectile(id)
			break
		end
	end
	-- Scroll to projectile
	if projectiles[id].follow==true then
		scroll(projectiles[id].x,projectiles[id].y)
	end
end
