--------------------------------------------------------------------------------
-- Weapon Anti-Gravity
-- Original Carnage Contest Weapon
-- Script by DC, February 2010, www.UnrealSoftware.de
-- modded by Kiffer-Opa
--------------------------------------------------------------------------------

-- Setup Tables
if ccm==nil then ccm={} end
ccm.antigravity={}

-- Load & Prepare Ressources
ccm.antigravity.gfx_wpn=loadgfx("weapons/antigravity.png")							-- Weapon Image
setmidhandle(ccm.antigravity.gfx_wpn)
ccm.antigravity.sfx_attack=loadsfx("antigravity.ogg")								-- antigravity Sound

--------------------------------------------------------------------------------
-- Weapon: Anti-Gravity
--------------------------------------------------------------------------------

ccm.antigravity.id=addweapon("ccm.antigravity","Anti-Gravity",ccm.antigravity.gfx_wpn,0,2)			-- Add Weapon (0 uses, first in round 2)
ccm.antigravity.power=200																		-- Power

function ccm.antigravity.draw()												-- Draw
	-- Partices
	if (weapon_shots>0) and (weapon_shots<ccm.antigravity.power) then
		if ((getframe()%5)==0) then
			players=playertable(0,0) -- All living players
			for i=1,#players,1 do
				particle(p_muzzle,getplayerx(players[i]),getplayery(players[i]))
				particlesize(0.7,0.7)
				particlecolor(100,255,255)
				particlealpha(0.5)
				particlefadealpha(0.01)
			end
			local myobjects=objecttable(0)
			for i=1,#myobjects,1 do
				local o=myobjects[i]
				local t=getobjecttype(o)
				if(t==o_supply or t==o_mine or t==o_beartrap or t==o_medikit) then
					particle(p_muzzle,getobjectx(o),getobjecty(o))
					if(t==o_mine) then
						particlesize(0.3,0.3)
					elseif(t==o_beartrap) then
						particlesize(0.3,0.2)
					elseif(t==o_supply or t==o_medikit) then
						particlesize(0.7,0.7)
					end
					particlealpha(0.5)
					particlefadealpha(0.01)
					particlecolor(100,255,255)
				end
			end
		end
	end

	-- icon above head
	if (weapon_shots<=0) then
		setblend(blend_alpha)
		setalpha(1)
		setcolor(255,255,255)
		drawimage(ccm.antigravity.gfx_wpn,getplayerx(0),getplayery(0)-(35+math.abs(math.sin(math.rad(weapon_charge)))*5))
		-- Animation
		weapon_charge=weapon_charge+5
	end
end

function ccm.antigravity.attack(attack)										-- Attack
	if (weapon_shots<=0) then
		if (attack==1) then
			-- No more weapon switching!
			useweapon(0)
			weapon_shots=1
			-- Make sure that there is enough round time
			secondsleft=math.floor(getframesleft()/50)
			changeturntime(30-secondsleft)
			-- Sound
			playsound(ccm.antigravity.sfx_attack)
		end
	end
	-- Anti-Gravity
	if (weapon_shots>0) then
		-- End
		if (weapon_shots>=ccm.antigravity.power) then
			endturn()
		else
			-- push players upwards
			local players=playertable(0,0) -- All living players
			for i=1,#players,1 do
				playerpush(players[i],getwind()*3.0,-2.4,1,1)
				
			end
			-- push supplies, mines, beartraps and medikits upwards
			local myobjects=objecttable(0)
			for i=1,#myobjects,1 do
				local o=myobjects[i]
				local t=getobjecttype(o)
				if(t==o_supply or t==o_mine or t==o_beartrap or t==o_medikit) then	
					
					local x,y,sx,sy
					x=getobjectx(o)
					y=getobjecty(o)
					sx=getwind()*3.0
					sy=-2.4
					
					local col
					if(t==o_supply or t==o_medikit) then
						col = col10x10
					elseif(t==o_mine) then
						col = col3x3
					elseif(t==o_beartrap) then
						col = col2x2
					else
						col = col5x5
					end

					-- Move (in substep loop for optimal collision precision)
					msubt=math.ceil(math.max(math.abs(sx),math.abs(sy))/3)
					msubx=sx/msubt
					msuby=sy/msubt
					for i=1,msubt,1 do
						-- Move X
						x=x+msubx
						if collision(col,x,y,1,0,0)==1 then
							x=x-msubx
							sx=-sx*0.3
							msubx=-msubx*0.3
						end
						-- Move Y
						y=y+msuby
						if collision(col,x,y,1,0,0)==1 then
							y=y-msuby
							sy=-sy*0.3
							msuby=-msuby*0.3
							sx=sx*0.9
							msubx=msubx*0.9
						end	
					end
					objectposition(o,x,y)
				end
			end
			-- Count Up
			weapon_shots=weapon_shots+1
		end
	end
end