-------------------------------------------------------------------------------
-- Weapon Pac-Man + Projectile Pac-Man
-- modified Carnage Contest Weapon
-- Script by DC, May 2010, www.UnrealSoftware.de
-- modified by Kiffer-Opa
--------------------------------------------------------------------------------

-- Setup Tables
if ccm==nil then ccm={} end
ccm.pacman={}
ccm.pacman.pacman={}

-- Load & Prepare Ressources
ccm.pacman.gfx_wpn0=loadgfx("weapons/pacman0.png")				-- Weapon Image Frame 0
setmidhandle(ccm.pacman.gfx_wpn0)
ccm.pacman.gfx_wpn1=loadgfx("weapons/pacman1.png")				-- Weapon Image Frame 1
setmidhandle(ccm.pacman.gfx_wpn1)
ccm.pacman.sfx_attack=loadsfx("pacman.ogg")					-- Pacman eating sound 
ccm.pacman.sfx_die=loadsfx("pacman_death.ogg")					-- Pacman's end sound
ccm.pacman.gfx_die={}								-- Pacman death frames
for i=1,8 do
	ccm.pacman.gfx_die[i] = loadgfx("weapons/pacman-"..i..".png")
	setmidhandle(ccm.pacman.gfx_die[i])
end

--------------------------------------------------------------------------------
-- Weapon: Pac-Man
--------------------------------------------------------------------------------

ccm.pacman.id=addweapon("ccm.pacman","Pac-Man",ccm.pacman.gfx_wpn0,0,3)	-- Add Weapon (0 uses, first in round 3)
ccm.pacman.dir=nil

function ccm.pacman.draw()										-- Draw
	-- Draw
	if weapon_shots<=0 then
		-- Info
		--hudinfo("Hit [Space] once to launch Pac-Man!")
		if getplayeraction(0)==0 then
			setblend(blend_alpha)
			setalpha(1)
			setcolor(255,255,255)
			if keydown(key_left)==1 then ccm.pacman.dir=-180 end
			if keydown(key_right)==1 then ccm.pacman.dir=0 end
			if keydown(key_up)==1 then ccm.pacman.dir=-90 end
			if keydown(key_down)==1 then ccm.pacman.dir=90 end
			if(ccm.pacman.dir==nil) then 
				if getplayerdirection(0)==1 then 
					ccm.pacman.dir=0
				else
					ccm.pacman.dir=-180
				end
			end
			setrotation(ccm.pacman.dir)
			
			drawimage(ccm.pacman.gfx_wpn0,getplayerx(0)+getplayerdirection(0)*7,getplayery(0)-5)

		end
	end
end

function ccm.pacman.attack(attack)									-- Attack
	if (weapon_shots<=0) then
		-- Fire a projectile (on release/full charge)
		if (attack==1) then
			-- No more weapon switching!
			useweapon(0)
			-- No more player control!
			playercontrol(0)
			-- Set Round Time (15 sec)
			secondsleft=math.floor(getframesleft()/50)
			changeturntime(15-secondsleft)
			-- Launch
			weapon_shots=weapon_shots+1
			id=createprojectile(ccm.pacman.pacman.id)
			projectiles[id]={}
			-- Set initial position of projectile
			projectiles[id].x=getplayerx(0)+getplayerdirection(0)*7
			projectiles[id].y=getplayery(0)-5
			-- Set direction of projectile
			projectiles[id].dir=ccm.pacman.dir
			-- Animation
			projectiles[id].frame=0
			projectiles[id].timer=0
			-- Timer
			weapon_timer=50
			-- Mode
			weapon_mode=1
		end
	end
end

--------------------------------------------------------------------------------
-- Projectile: Pac-Man
--------------------------------------------------------------------------------

ccm.pacman.pacman.id=addprojectile("ccm.pacman.pacman")			-- Add Projectile

function ccm.pacman.pacman.draw(id)								-- Draw
	-- Setup draw mode
	setblend(blend_alpha)
	setalpha(1)
	setcolor(255,255,255)
	setscale(1,1)
	setrotation(projectiles[id].dir)
	-- Draw projectile
	if(weapon_mode==2) then	-- dieing mode
		if(weapon_timer>=45) then
			drawimage(ccm.pacman.gfx_wpn0, projectiles[id].x, projectiles[id].y-2)
		elseif(weapon_timer>=5) then
			local frame 
			if(weapon_timer>=40) then
				frame = 1
			elseif(weapon_timer>=35) then
				frame = 2
			elseif(weapon_timer>=30) then
				frame = 3
			elseif(weapon_timer>=25) then
				frame = 4
			elseif(weapon_timer>=20) then
				frame = 5
			elseif(weapon_timer>=15) then
				frame = 6
			elseif(weapon_timer>=10) then
				frame = 7
			else
				frame = 8
			end
			drawimage(ccm.pacman.gfx_die[frame], projectiles[id].x, projectiles[id].y-2)
		end
	else	-- normal mode
		if projectiles[id].frame==0 then
			drawimage(ccm.pacman.gfx_wpn0,projectiles[id].x,projectiles[id].y-2)
		else
			drawimage(ccm.pacman.gfx_wpn1,projectiles[id].x,projectiles[id].y-2)
		end
	end
	-- Draw Arrow if out of Screen
	outofscreenarrow(projectiles[id].x,projectiles[id].y)
	-- Info
	hudinfo("Control Pac-Man with your arrow keys or W/A/S/D!")
end

function ccm.pacman.pacman.update(id)							-- Update
	-- Timer
	weapon_timer=weapon_timer-1
	projectiles[id].timer=projectiles[id].timer+1

	if weapon_mode==1 then
		-- Animation
		if projectiles[id].timer>6 then
			projectiles[id].timer=0
			projectiles[id].frame=1-projectiles[id].frame
			-- Bite
			if projectiles[id].frame==0 then
				playsound(ccm.pacman.sfx_attack,0)
				if collision(ccm.pacman.gfx_wpn1,projectiles[id].x,projectiles[id].y,1,0,0)==1 then
					-- Eat Terrain
					terraincircle(projectiles[id].x,projectiles[id].y,17,0x00000000)
				end
			end
		end
		-- Control
		if keydown(key_left)==1 then projectiles[id].dir=-180 end
		if keydown(key_right)==1 then projectiles[id].dir=0 end
		if keydown(key_up)==1 then projectiles[id].dir=-90 end
		if keydown(key_down)==1 then projectiles[id].dir=90 end
		-- Move
		if projectiles[id].dir==-180 then
			projectiles[id].x=projectiles[id].x-1
		elseif projectiles[id].dir==0 then
			projectiles[id].x=projectiles[id].x+1
		elseif projectiles[id].dir==-90 then
			projectiles[id].y=projectiles[id].y-1
		elseif projectiles[id].dir==90 then
			projectiles[id].y=projectiles[id].y+1
		end
		-- Water
		if (projectiles[id].y)>getwatery()-20 then
			-- Effects
			particle(p_waterhit,projectiles[id].x,projectiles[id].y)
			playsound(sfx_hitwater3)
			-- Free projectile
			freeprojectile(id)
			-- End Turn
			endturn()
			return
		-- Timer / Explode
		elseif getframesleft()<5 or (weapon_timer<=0 and keydown(key_attack)==1) then
			weapon_mode=2
			weapon_timer=50
			playsound(ccm.pacman.sfx_die)
		end
	elseif(weapon_mode==2) then
		if(weapon_timer==0) then
			-- Cause damage
			arealdamage(projectiles[id].x,projectiles[id].y,60,30)
			-- Destroy terrain
			terraincircle(projectiles[id].x,projectiles[id].y,50,0x00000000)
			-- Crater
			grey=math.random(0,40)
			terrainalphaimage(gfx_crater150,projectiles[id].x,projectiles[id].y,math.random(6,9)*0.1,227,227,0)
			-- Ring animation
			particle(p_ring,projectiles[id].x,projectiles[id].y)
		elseif(weapon_timer==-10) then
			-- ring animation
			particle(p_ring,projectiles[id].x,projectiles[id].y)
			-- reset variables
			ccm.pacman.dir=nil
			-- free pacman
			freeprojectile(id)
			-- end turn
			endturn()
			return
		end
			
	end
	-- Scroll to projectile
	scroll(projectiles[id].x,projectiles[id].y)
end
